X-Git-Url: https://git.p6c8.net/jirafeau_mojo42.git/blobdiff_plain/df31fed41e6f10218a99ece4a4f47571eea360f5..9493cba088d6a0554687ecba4091f72c19300f1d:/lib/functions.php
diff --git a/lib/functions.php b/lib/functions.php
index b3dc904..1444c1f 100644
--- a/lib/functions.php
+++ b/lib/functions.php
@@ -20,7 +20,7 @@
*/
/**
- * Transform a string in a path by seperating each letters by a '/'.
+ * Transform a string in a path by separating each letters by a '/'.
* @return path finishing with a '/'
*/
function s2p($s)
@@ -28,7 +28,7 @@ function s2p($s)
$block_size = 8;
$p = '';
for ($i = 0; $i < strlen($s); $i++) {
- $p .= $s{$i};
+ $p .= $s[$i];
if (($i + 1) % $block_size == 0) {
$p .= '/';
}
@@ -68,16 +68,16 @@ function base_16_to_64($num)
# Convert long hex string to bin.
$size = strlen($num);
for ($i = 0; $i < $size; $i++) {
- $b .= $hex2bin{hexdec($num{$i})};
+ $b .= $hex2bin[hexdec($num[$i])];
}
# Convert long bin to base 64.
$size *= 4;
for ($i = $size - 6; $i >= 0; $i -= 6) {
- $o = $m{bindec(substr($b, $i, 6))} . $o;
+ $o = $m[bindec(substr($b, $i, 6))] . $o;
}
# Some few bits remaining ?
if ($i < 0 && $i > -6) {
- $o = $m{bindec(substr($b, 0, $i + 6))} . $o;
+ $o = $m[bindec(substr($b, 0, $i + 6))] . $o;
}
return $o;
}
@@ -418,7 +418,7 @@ function jirafeau_upload($file, $one_time_download, $key, $time, $ip, $crypt, $l
}
}
- /* file informations */
+ /* file information */
$hash = jirafeau_hash_file($file_hash_method, $file['tmp_name']);
$name = str_replace(NL, '', trim($file['name']));
$mime_type = $file['type'];
@@ -509,10 +509,15 @@ function jirafeau_upload($file, $one_time_download, $key, $time, $ip, $crypt, $l
function jirafeau_is_viewable($mime)
{
if (!empty($mime)) {
- /* Actually, verify if mime-type is an image or a text. */
- $viewable = array('image', 'text', 'video', 'audio');
+ $viewable = array('image', 'video', 'audio');
$decomposed = explode('/', $mime);
- return in_array($decomposed[0], $viewable);
+ if (in_array($decomposed[0], $viewable) && strpos($mime, 'image/svg+xml') === false) {
+ return true;
+ }
+ $viewable = array('text/plain');
+ if (in_array($mime, $viewable)) {
+ return true;
+ }
}
return false;
}
@@ -588,8 +593,8 @@ function check_errors($cfg)
}
/**
- * Read link informations
- * @return array containing informations.
+ * Read link information
+ * @return array containing information.
*/
function jirafeau_get_link($hash)
{
@@ -654,7 +659,7 @@ function jirafeau_admin_list($name, $file_hash, $link_hash)
/* Push new found directory. */
$stack[] = $d . $node . '/';
} elseif (is_file($d . $node)) {
- /* Read link informations. */
+ /* Read link information. */
$l = jirafeau_get_link($node);
if (!count($l)) {
continue;
@@ -670,7 +675,7 @@ function jirafeau_admin_list($name, $file_hash, $link_hash)
if (!empty($link_hash) && $link_hash != $node) {
continue;
}
- /* Print link informations. */
+ /* Print link information. */
echo '
';
echo '' .
'' .
'' .
@@ -730,7 +737,7 @@ function jirafeau_admin_clean()
/* Push new found directory. */
$stack[] = $d . $node . '/';
} elseif (is_file($d . $node)) {
- /* Read link informations. */
+ /* Read link information. */
$l = jirafeau_get_link(basename($node));
if (!count($l)) {
continue;
@@ -750,7 +757,7 @@ function jirafeau_admin_clean()
/**
- * Clean old async transferts.
+ * Clean old async transfers.
* @return number of cleaned files.
*/
function jirafeau_admin_clean_async()
@@ -771,12 +778,12 @@ function jirafeau_admin_clean_async()
/* Push new found directory. */
$stack[] = $d . $node . '/';
} elseif (is_file($d . $node)) {
- /* Read async informations. */
+ /* Read async information. */
$a = jirafeau_get_async_ref(basename($node));
if (!count($a)) {
continue;
}
- /* Delete transferts older than 1 hour. */
+ /* Delete transfers older than 1 hour. */
if (time() - $a['last_edited'] > 3600) {
jirafeau_async_delete(basename($node));
$count++;
@@ -786,9 +793,107 @@ function jirafeau_admin_clean_async()
}
return $count;
}
+
+/**
+ * Better strval function for debug purposes
+ */
+function jirafeau_strval($value)
+{
+ if (gettype($value) == "boolean") {
+ return $value ? 'true' : 'false';
+ }
+ return strval($value);
+}
+
+/**
+ * Show file/folder permissions
+ */
+function jirafeau_fileperms($path)
+{
+ $out = substr(sprintf("%o", @fileperms($path)), -4) . ", ";
+ $out .= "read " . (is_readable($path) ? "OK" : "KO") . ", ";
+ $out .= "write " . (is_writable($path) ? "OK" : "KO");
+ return $out;
+}
+
+/**
+ * Show some useful informations for bug reporting.
+ */
+function jirafeau_admin_bug_report($cfg)
+{
+ $out = "";
+ return $out;
+}
+
/**
* Read async transfert informations
* @return array containing informations.
*/
function jirafeau_get_async_ref($ref)
{
@@ -812,7 +917,7 @@ function jirafeau_get_async_ref($ref)
}
/**
* Delete async transfert informations
*/
function jirafeau_async_delete($ref)
{
@@ -836,17 +941,15 @@ function jirafeau_async_delete($ref)
/**
* Init a new asynchronous upload.
- * @param $finename Name of the file to send
+ * @param $filename Name of the file to send
* @param $one_time One time upload parameter
* @param $key eventual password (or blank)
* @param $time time limit
* @param $ip ip address of the client
- * @return a string containing a temporary reference followed by a code or the string 'Error'
+ * @return a string containing a temporary reference followed by a code or a string starting with 'Error'
*/
function jirafeau_async_init($filename, $type, $one_time, $key, $time, $ip)
{
- $res = 'Error';
-
/* Create temporary folder. */
$ref;
$p;
@@ -857,8 +960,7 @@ function jirafeau_async_init($filename, $type, $one_time, $key, $time, $ip)
} while (file_exists($p));
@mkdir($p, 0755, true);
if (!file_exists($p)) {
- echo 'Error';
- return;
+ return 'Error: cannot create async folder.';
}
/* touch empty data file */
@@ -871,7 +973,7 @@ function jirafeau_async_init($filename, $type, $one_time, $key, $time, $ip)
$password = md5($key);
}
- /* Store informations. */
+ /* Store information. */
$p .= $ref;
$handle = fopen($p, 'w');
fwrite(
@@ -892,7 +994,7 @@ function jirafeau_async_init($filename, $type, $one_time, $key, $time, $ip)
* @param $file piece of data
* @param $code client code for this operation
* @param $max_file_size maximum allowed file size
- * @return a string containing a next code to use or the string "Error"
+ * @return a string containing a next code to use or a string starting with 'Error'
*/
function jirafeau_async_push($ref, $data, $code, $max_file_size)
{
@@ -900,11 +1002,17 @@ function jirafeau_async_push($ref, $data, $code, $max_file_size)
$a = jirafeau_get_async_ref($ref);
/* Check some errors. */
- if (count($a) == 0
- || $a['next_code'] != "$code"
- || empty($data['tmp_name'])
- || !is_uploaded_file($data['tmp_name'])) {
- return 'Error';
+ if (count($a) == 0) {
+ return "Error: cannot find transfer";
+ }
+ if ($a['next_code'] != "$code") {
+ return "Error: bad transfer code";
+ }
+ if (empty($data['tmp_name'])) {
+ return "Error: missing tmp_name";
+ }
+ if (!is_uploaded_file($data['tmp_name'])) {
+ return "Error: tmp_name may not be uploaded";
}
$p = s2p($ref);
@@ -917,7 +1025,7 @@ function jirafeau_async_push($ref, $data, $code, $max_file_size)
if ($max_file_size > 0 &&
filesize($r_path) + filesize($w_path) > $max_file_size * 1024 * 1024) {
jirafeau_async_delete($ref);
- return 'Error';
+ return "Error: file size is above upload limit";
}
/* Concatenate data. */
@@ -928,7 +1036,7 @@ function jirafeau_async_push($ref, $data, $code, $max_file_size)
fclose($r);
fclose($w);
jirafeau_async_delete($ref);
- return 'Error';
+ return "Error: cannot write file";
}
}
fclose($r);
@@ -949,12 +1057,12 @@ function jirafeau_async_push($ref, $data, $code, $max_file_size)
}
/**
- * Finalyze an asynchronous upload.
+ * Finalize an asynchronous upload.
* @param $ref asynchronous upload reference
* @param $code client code for this operation
* @param $crypt boolean asking to crypt or not
* @param $link_name_length link name length
- * @return a string containing the download reference followed by a delete code or the string 'Error'
+ * @return a string containing the download reference followed by a delete code or a string starting with 'Error'
*/
function jirafeau_async_end($ref, $code, $crypt, $link_name_length, $file_hash_method)
{
@@ -962,13 +1070,13 @@ function jirafeau_async_end($ref, $code, $crypt, $link_name_length, $file_hash_m
$a = jirafeau_get_async_ref($ref);
if (count($a) == 0
|| $a['next_code'] != "$code") {
- return "Error";
+ return "Error: bad code for ending transfer";
}
/* Generate link infos. */
$p = VAR_ASYNC . s2p($ref) . $ref . "_data";
if (!file_exists($p)) {
- return 'Error';
+ return "Error: referenced file does not exist";
}
$crypted = false;
@@ -1016,9 +1124,11 @@ function jirafeau_async_end($ref, $code, $crypt, $link_name_length, $file_hash_m
fclose($handle);
$hash_link = substr(base_16_to_64(md5_file($link_tmp_name)), 0, $link_name_length);
$l = s2p("$hash_link");
- if (!@mkdir(VAR_LINKS . $l, 0755, true) ||
- !rename($link_tmp_name, VAR_LINKS . $l . $hash_link)) {
- return 'Error';
+ if (!@mkdir(VAR_LINKS . $l, 0755, true)) {
+ return "Error: cannot create folder in LINKS";
+ }
+ if (!rename($link_tmp_name, VAR_LINKS . $l . $hash_link)) {
+ return "Error: cannot rename file in LINKS";
}
/* Clean async upload. */
@@ -1426,3 +1536,8 @@ function jirafeau_add_ending_slash($path)
{
return $path . ((substr($path, -1) == '/') ? '' : '/');
}
+
+function jirafeau_default_web_root()
+{
+ return $_SERVER['HTTP_HOST'] . str_replace(basename(__FILE__), '', $_SERVER['REQUEST_URI']);
+}
|
@@ -786,9 +793,107 @@ function jirafeau_admin_clean_async()
/**
- * Read async transfert informations
- * @return array containing informations.
+ * Read async transfer information
+ * @return array containing information.
*/
function jirafeau_get_async_ref($ref)
@@ -812,7 +917,7 @@ function jirafeau_get_async_ref($ref)
}
/**
- * Delete async transfert informations
+ * Delete async transfer information
*/
function jirafeau_async_delete($ref)